# Table of Contents

- [documentation-on-sap-help-portal](<./documentation-on-sap-help-portal.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Welcome to the New Home of SAP LeanIX Documentation](<./Welcome-to-the-New-Home-of-SAP-LeanIX-Documentation.md>)
  - [Choose a Language](<./Welcome-to-the-New-Home-of-SAP-LeanIX-Documentation/Choose-a-Language.md>)
  - [Search in Your Preferred Language](<./Welcome-to-the-New-Home-of-SAP-LeanIX-Documentation/Search-in-Your-Preferred-Language.md>)
  - [Download PDF Files](<./Welcome-to-the-New-Home-of-SAP-LeanIX-Documentation/Download-PDF-Files.md>)
  - [Browse Topics](<./Welcome-to-the-New-Home-of-SAP-LeanIX-Documentation/Browse-Topics.md>)
  - [Share Your Feedback](<./Welcome-to-the-New-Home-of-SAP-LeanIX-Documentation/Share-Your-Feedback.md>)
